@@ -15,7 +15,7 @@ use List::MoreUtils                 qw(any firstval);
 
 use Mojolicious::Plugin::Vparam::Address;
 
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 
 =encoding utf-8
 
@@ -197,6 +197,17 @@ Get parameter error string. Return 0 if no error.
     # Set error
     $self->verror('myparam', {message => 'Error message'})
 
+=head2 vclass $name, @classes
+
+Get classes for invalid input. Return empty string if no error.
+
+    # Form example
+    <input name="myparam" class="<%= vclass 'myparam' %>">
+    # Return next code for invalid I<myparam>:
+    # <input name="myparam" class="field-with-error">
+
+You can set additional I<@classes> to set if field invalid.
+
 =head2 verrors
 
 Return erorrs count in scalar context. In list context return erorrs hash.
@@ -279,6 +290,10 @@ Apply as L</in> filter. No type verification, just match.
 
 =over
 
+=item class
+
+CSS class for invalid parameters. Default: field-with-error.
+
 =item types
 
 You can simple add you own types.
@@ -1160,6 +1175,7 @@ sub register {
 
     $conf                   ||= {};
 
+    $conf->{class}          ||= 'field-with-error';
     $conf->{types}          ||= {};
     $conf->{filters}        ||= {};
 
@@ -1244,7 +1260,7 @@ sub register {
             valid   => sub { _check_date        $_[1] },
             post    => sub {
                 return unless defined $_[1];
-                return $conf->{date}
+                return $conf->{date} && ref $_[1]
                     ? $_[1]->strftime( $conf->{date} )
                     : $_[1];
             },
@@ -1254,7 +1270,7 @@ sub register {
             valid   => sub { _check_time        $_[1] },
             post    => sub {
                 return unless defined $_[1];
-                return $conf->{time}
+                return $conf->{time} && ref $_[1]
                     ? $_[1]->strftime( $conf->{time} )
                     : $_[1];
             },
@@ -1264,7 +1280,7 @@ sub register {
             valid   => sub { _check_datetime    $_[1] },
             post    => sub {
                 return unless defined $_[1];
-                return $conf->{datetime}
+                return $conf->{datetime} && ref $_[1]
                     ? $_[1]->strftime( $conf->{datetime} )
                     : $_[1];
             },
@@ -1393,6 +1409,19 @@ sub register {
         }
     });
 
+    # Return string if parameter have error, else empty string.
+    $app->helper(vclass => sub{
+        my ($self, $name, @classes) = @_;
+        return '' unless $self->verror( $name );
+
+        my @class;
+        push @class, $conf->{class}
+            if defined($conf->{class}) && length($conf->{class});
+        push @class, @classes;
+
+        return join ' ', @class;
+    });
+
     # Return all errors as Hash or errors count in scalar context.
     $app->helper(verrors => sub{
         my ($self) = @_;
